scipy.sparse.base
=================

.. automodule:: scipy.sparse.base

   
   
   .. rubric:: Functions

   .. autosummary::
   
      isdense
      isintlike
      isscalarlike
      issparse
      isspmatrix
      warn
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      spmatrix
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      SparseEfficiencyWarning
      SparseFormatWarning
      SparseWarning
   
   